﻿SystemOrganization addCategory: #ConfigurationOfMessagePack!

Object subclass: #ConfigurationOfMessagePack
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMessagePack'!

!ConfigurationOfMessagePack class methodsFor: 'private' stamp: 'mu 6/2/2011 15:05'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMessagePack class methodsFor: 'development support' stamp: 'mu 6/2/2011 15:05'!
compareVersions
	"Compare previous version to development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfMessagePack class methodsFor: 'development support' stamp: 'mu 6/2/2011 15:05'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfMessagePack class methodsFor: 'private' stamp: 'mu 6/2/2011 15:05'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfMessagePack class methodsFor: 'metacello tool support' stamp: 'mu 6/2/2011 15:05'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfMessagePack class methodsFor: 'metacello tool support' stamp: 'mu 6/2/2011 15:05'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMessagePack class methodsFor: 'loading' stamp: 'mu 6/2/2011 15:05'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfMessagePack class methodsFor: 'metacello tool support' stamp: 'mu 6/2/2011 15:05'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMessagePack class methodsFor: 'accessing' stamp: 'mu 6/2/2011 15:05'!
project

	^self new project! !

!ConfigurationOfMessagePack class methodsFor: 'development support' stamp: 'mu 6/2/2011 15:05'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- fixed a bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfMessagePack methodsFor: 'baselines' stamp: 'mu 6/2/2011 15:47'!
baseline100: spec 
	<version: '1.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			repository: 'http://www.squeaksource.com/MessagePack'.
		spec 
			package: 'MessagePack-Core';
			package: 'MessagePackTest-Core' with: [ spec requires: 'MessagePack-Core' ].
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('MessagePack-Core');
			group: 'Tests' with: #('MessagePackTest-Core'). ].
	
	spec for: #squeakCommon do: [
		spec 
			package: 'MessagePack-Squeak-Core' with: [ spec requires: 'MessagePack-Core' ]. 
		spec
			group: 'Core' with: #('MessagePack-Squeak-Core'). ].
	! !

!ConfigurationOfMessagePack methodsFor: 'baselines' stamp: 'dkh 8/26/2011 03:32'!
baseline101: spec 
	<version: '1.0.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			repository: 'http://www.squeaksource.com/MessagePack'.
		spec 
			package: 'MessagePack-Core';
			package: 'MessagePackTest' with: [ spec requires: 'MessagePack-Core' ].
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('MessagePack-Core');
			group: 'Tests' with: #('MessagePackTest'). ].
	
	spec for: #squeakCommon do: [
		spec 
			package: 'MessagePack-Squeak-Core' with: [ spec requires: 'MessagePack-Core' ]. 
		spec
			group: 'Core' with: #('MessagePack-Squeak-Core'). ].
	! !

!ConfigurationOfMessagePack methodsFor: 'symbolic versions' stamp: 'mu 6/2/2011 15:05'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfMessagePack methodsFor: 'accessing' stamp: 'mu 6/2/2011 15:05'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!ConfigurationOfMessagePack methodsFor: 'symbolic versions' stamp: 'mu 7/16/2011 01:04'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'common' version: '1.0.2'.! !

!ConfigurationOfMessagePack methodsFor: 'versions' stamp: 'mu 6/2/2011 17:47'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			package: 'MessagePack-Core' with: 'MessagePack-Core-mu.4';
			package: 'MessagePackTest-Core' with: 'MessagePackTest-mu.2' ].
	spec for: #squeakCommon do: [
		spec 
			package: 'MessagePack-Squeak-Core' with: 'MessagePack-Squeak-Core-mu.1'].! !

!ConfigurationOfMessagePack methodsFor: 'versions' stamp: 'mu 11/23/2011 22:44'!
version101: spec 
	<version: '1.0.1' imports: #('1.0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Masashi Umezawa'.
		spec 
			package: 'MessagePack-Core' with: 'MessagePack-Core-mu.6';
			package: 'MessagePackTest' with: 'MessagePackTest-mu.2' ].
	spec for: #squeakCommon do: [
		spec 
			package: 'MessagePack-Squeak-Core' with: 'MessagePack-Squeak-Core-mu.1'].! !

!ConfigurationOfMessagePack methodsFor: 'versions' stamp: 'mu 11/23/2011 22:44'!
version102: spec 
	<version: '1.0.2' imports: #('1.0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Masashi Umezawa'.
		spec 
			package: 'MessagePack-Core' with: 'MessagePack-Core-mu.8';
			package: 'MessagePackTest' with: 'MessagePackTest-mu.3' ].
	spec for: #squeakCommon do: [
		spec 
			package: 'MessagePack-Squeak-Core' with: 'MessagePack-Squeak-Core-mu.1'].! !

!ConfigurationOfMessagePack methodsFor: 'versions' stamp: 'mu 11/23/2011 22:58'!
version103: spec 
	<version: '1.0.3' imports: #('1.0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			package: 'MessagePack-Core' with: 'MessagePack-Core-mu.15';
			package: 'MessagePackTest' with: 'MessagePackTest-mu.3' ].
	spec for: #squeakCommon do: [
		spec 
			package: 'MessagePack-Squeak-Core' with: 'MessagePack-Squeak-Core-mu.2'].! !
